@@ -93,7 +93,9 @@ module Linguist
       generated_dart? ||
       generated_perl_ppport_header? ||
       generated_gamemakerstudio? ||
-      generated_gimp?
+      generated_gimp? ||
+      generated_visualstudio6? ||
+      generated_haxe?
     end
 
     # Internal: Is the blob an Xcode file?
@@ -299,7 +301,7 @@ module Linguist
       return false unless extname == '.go'
       return false unless lines.count > 1
 
-      return lines[0].include?("Code generated by")
+      return lines.first(10).any? { |l| l.include? "Code generated by" }
     end
 
     PROTOBUF_EXTENSIONS = ['.py', '.java', '.h', '.cc', '.cpp', '.m', '.rb']
@@ -603,7 +605,7 @@ module Linguist
       return lines[2].match(/\"modelName\"\:\s*\"GM/) ||
              lines[0] =~ /^\d\.\d\.\d.+\|\{/
     end
-        
+
     # Internal: Is this a generated GIMP C image file?
     #
     # GIMP saves C sources with one of two comment forms:
@@ -618,6 +620,24 @@ module Linguist
              lines[0].match(/\/\*  GIMP header image file format \([a-zA-Z0-9\- ]+\)\: .+?\.h  \*\//)
     end
 
+    # Internal: Is this a generated Microsoft Visual Studio 6.0 build file?
+    #
+    # Return true or false
+    def generated_visualstudio6?
+      return false unless extname.downcase == '.dsp'
+      lines.first(3).any? { |l| l.include? '# Microsoft Developer Studio Generated Build File' }
+    end
+
+    HAXE_EXTENSIONS = ['.js', '.py', '.lua', '.cpp', '.h', '.java', '.cs', '.php']
+
+    # Internal: Is this a generated Haxe-generated source file?
+    #
+    # Return true or false
+    def generated_haxe?
+      return false unless HAXE_EXTENSIONS.include?(extname)
+      return lines.first(3).any? { |l| l.include?("Generated by Haxe") }
+    end
+
     # Internal: Is this a generated HTML file?
     #
     # HTML documents generated by authoring tools often include a
